@@ -21,9 +21,36 @@
  */
 package com.zwitserloot.ivyplusplus.eclipse;
 
-import lombok.Data;
-
-@Data
 public class Apt {
 	private String location;
+	
+	public String getLocation() {
+		return location;
+	}
+	
+	public void setLocation(String location) {
+		this.location = location;
+	}
+	
+	@Override public String toString() {
+		return "Apt [location=" + location + "]";
+	}
+	
+	@Override public int hashCode() {
+		final int prime = 31;
+		int result = 1;
+		result = prime * result + ((location == null) ? 0 : location.hashCode());
+		return result;
+	}
+	
+	@Override public boolean equals(Object obj) {
+		if (this == obj) return true;
+		if (obj == null) return false;
+		if (getClass() != obj.getClass()) return false;
+		Apt other = (Apt) obj;
+		if (location == null) {
+			if (other.location != null) return false;
+		} else if (!location.equals(other.location)) return false;
+		return true;
+	}
 }
